<?php

namespace Drupal\permission_matrix\Form;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class PermissionGroupForm.
 */
class PermissionGroupForm extends EntityForm {

  /**
   * get Permissions
   */
  private function getSavedPermissions() {
    $permission_config = $this->config('permission_matrix.config')->get('permission_matrix_config');
    $result = json_decode($permission_config);
    $permissions_array = [];
    foreach ($result as $val) {
      $permissions_array[$val->permission] = $val->permission_label;
    }
    return $permissions_array;
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);
    $config_permissions = $this->getSavedPermissions();
    $permission_group = $this->entity;
    $permission_group_default = $this->getGroupPermission($this->entity);

    $form['label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#maxlength' => 255,
      '#default_value' => $permission_group->label(),
      '#description' => $this->t("Label for the Permission group."),
      '#required' => TRUE,
    ];

    $form['id'] = [
      '#type' => 'machine_name',
      '#default_value' => $permission_group->id(),
      '#machine_name' => [
        'exists' => '\Drupal\permission_matrix\Entity\PermissionGroup::load',
      ],
      '#disabled' => !$permission_group->isNew(),
    ];

    $form['permissions'] = [
      '#title' => $this->t('Select Permission to group'),
      '#type' => 'checkboxes',
      '#options' => $config_permissions,
      '#default_value' => $permission_group_default,
    ];
       
    /* You will need additional form elements for your custom properties. */

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $permission_group = $this->entity;
    $status = $permission_group->save();
    switch ($status) {
      case SAVED_NEW:
        drupal_set_message($this->t('Created the %label Permission group.', [
          '%label' => $permission_group->label(),
        ]));
        break;

      default:
        drupal_set_message($this->t('Saved the %label Permission group.', [
          '%label' => $permission_group->label(),
        ]));
    }
    $form_state->setRedirectUrl($permission_group->toUrl('collection'));
  }

  /**
   * {@inheritdoc}
   */
  private function getGroupPermission($entity) {
    $permissions = $entity->get('permissions');
    $perm = [];
    foreach ($permissions as $key=>$val) {
      if ($val <> "") {
        $perm[] = $val;
      }
    }
    return $perm;
  }
  
}
